@@ -56,6 +56,9 @@ email_clicked (GtkWidget *w, gint button, gpointer data)
 	    fflush (sendmail);
 	    
 	    pclose (sendmail);
+	    
+	    gnome_config_set_string ("/Editor_Plugins/Email/From", from);
+	    gnome_config_sync ();
 	  }
 	gnome_dialog_close( GNOME_DIALOG( w ) );
 }
@@ -115,6 +118,12 @@ main (int argc, char *argv[])
 	hostname = getenv ("HOSTNAME");
 	/*printf ("%s\n", hostname);*/
 	
+	if (gnome_config_get_string ("/Editor_Plugins/Email/From"))
+	  {
+	    gtk_entry_set_text (GTK_ENTRY (from_entry), 
+	    					gnome_config_get_string ("/Editor_Plugins/Email/From"));
+	  }
+	else
 	if (user)
 	{
 		pw = getpwnam (user);
