@@ -17,21 +17,9 @@
 #ifndef __MAINCODE_H__
 #define __MAINCODE_H__
 #define PROGRAMTITLE "Projektmanager"
-#define VERSION "0.0.1"
-typedef struct _prj_manager_menubar
-{
-	GtkWidget *bar;
-	
-	
-	GtkWidget *fileroot;
-	GtkWidget *filemenu;
-	GtkWidget *filemenu_open;
-	GtkWidget *filemenu_new;
-	
-	GtkWidget *helproot;
-	GtkWidget *helpmenu;
-	GtkWidget *helpmenu_about;
-}prj_manager_menubar;
+#define PRJVERSION "0.0.1"
+
+
 typedef struct _prj_manager_window
 {
 	gint selectedrow;	
@@ -39,12 +27,14 @@ typedef struct _prj_manager_window
 	gint plugin_context;
 	GtkWidget *window;
 	GtkWidget *vbox;
-	prj_manager_menubar *menubar;
 	GtkWidget *scroller;
 	GtkWidget *tree;
 	GtkWidget *treeroot;
+	GtkWidget *scrwindow;
+	
 	char test[24];
 }prj_manager_window;
+
 typedef struct _prj_data
 {	
 	prj_manager_window * ptr;
@@ -53,6 +43,7 @@ typedef struct _prj_data
 	GtkWidget *widget;
 	gpointer temp2;
 }prj_data;
+
 typedef struct _prj_tree_data
 {
 	gpointer treedataroot;
@@ -61,4 +52,5 @@ typedef struct _prj_tree_data
 		gchar *filename;
 		gchar *path;
 }prj_tree_data;
+
 #endif
