@@ -36,30 +36,38 @@
 
 #include "main.h"
 #include "commands.h"
+#include "gE_mdi.h"
 #include "gE_document.h"
 #include "gE_prefs.h"
 #include "gE_files.h"
 #include "gE_plugin_api.h"
 #include "dialog.h"
+#include "search.h"
 
 static void close_file_save_yes_sel (GtkWidget *w, gE_data *data);
 static void close_file_save_cancel_sel(GtkWidget *w, gE_data *data);
 static void close_file_save_no_sel(GtkWidget *w, gE_data *data);
 static void close_doc_common(gE_data *data);
 static void close_window_common(gE_window *w);
-static gint file_saveas_destroy(GtkWidget *w, gpointer cbdata);
+static gint file_saveas_destroy(GtkWidget *w, GtkWidget **sel);
 static gint file_cancel_sel (GtkWidget *w, GtkFileSelection *fs);
-static gint file_sel_destroy (GtkWidget *w, GtkFileSelection *fs);
+static void file_sel_destroy (GtkWidget *w, GtkFileSelection *fs);
 static void line_pos_cb(GtkWidget *w, gE_data *data);
-static void recent_update_menus (gE_window *window, GList *recent_files);
+static void recent_update_menus (GnomeApp *app, GList *recent_files);
 static void recent_cb(GtkWidget *w, gE_data *data);
 
+static GtkWidget *open_fs, *save_fs;
+GtkWidget *ssel = NULL;
+GtkWidget *osel = NULL;
+GtkWidget *col_label;
+gchar *oname = NULL;
 
 /* handles changes in the text widget... */
 void
 doc_changed_cb(GtkWidget *w, gpointer cbdata)
 {
 gchar MOD_label[255];
+gchar *str;
 
 	gE_document *doc = (gE_document *) cbdata;
 
@@ -67,8 +75,19 @@ gchar MOD_label[255];
 	gtk_signal_disconnect (GTK_OBJECT(doc->text), (gint) doc->changed_id);
 	doc->changed_id = FALSE;
 	
-	sprintf(MOD_label, "*%s", GTK_LABEL(doc->tab_label)->label);
-	gtk_label_set(GTK_LABEL(doc->tab_label), MOD_label);
+	str = g_malloc (strlen (GNOME_MDI_CHILD(doc)->name) + 2);
+	
+	sprintf(str, "*%s", GNOME_MDI_CHILD(doc)->name);
+	/*gtk_label_set(GTK_LABEL(doc->tab_label), MOD_label);*/
+	gnome_mdi_child_set_name (GNOME_MDI_CHILD (doc), str);
+	
+	g_free (str);
+	
+	str = g_malloc0 (strlen (GEDIT_ID) +
+				 strlen (GNOME_MDI_CHILD (gE_document_current())->name) + 4);
+	sprintf (str, "%s - %s", GNOME_MDI_CHILD (gE_document_current())->name, GEDIT_ID);
+	gtk_window_set_title(GTK_WINDOW(mdi->active_window), str);
+	g_free(str);
 }
 
 
@@ -79,7 +98,8 @@ static void
 close_file_save_no_sel(GtkWidget *w, gE_data *data)
 {
 	g_assert(data != NULL);
-	close_doc_execute(NULL, data);
+	/*close_doc_execute(NULL, data);*/
+	file_close_cb (w, data);
 	data->temp1 = NULL;
 	data->temp2 = NULL;
 	data->flag = TRUE;
@@ -101,14 +121,16 @@ close_file_save_yes_sel(GtkWidget *w, gE_data *data)
 		data->temp1 = NULL;
 		file_save_as_cb(w, data);
 		if (data->flag == TRUE) /* close document if successful */
-			close_doc_execute(NULL, data);
+		     file_close_cb (w, data);
+			/*close_doc_execute(NULL, data);*/
 	} else {
 		int error;
 
-		error = gE_file_save(data->window, doc, doc->filename);
+		error = gE_file_save(doc, doc->filename);
 		if (!error) {
 			data->temp1 = NULL;
-			close_doc_execute(NULL, data);
+			/*close_doc_execute(NULL, data);*/
+			file_close_cb (w, data);
 			data->temp2 = NULL;
 			data->flag = TRUE;
 		} else
@@ -179,117 +201,16 @@ popup_close_verify(gE_document *doc, gE_data *data)
 } /* popup_close_verify */
 
 
-/*
- * file open callback : user selects "Ok"
- */
-gint
-file_open_ok_sel(GtkWidget *widget, gE_data *data)
-{
-	char *filename;
-	char *nfile;
-	struct stat sb;
-	gE_window *w;
-	gE_document *curdoc;
-	GtkFileSelection *fs;
-
-
-	g_assert(data != NULL);
-	w = data->window;
-	g_assert(w != NULL);
-	fs = GTK_FILE_SELECTION(w->open_fileselector);
-
-	filename = gtk_file_selection_get_filename(fs);
-
-	if (filename != NULL) {
-		if (stat(filename, &sb) == -1)
-			return TRUE;
-
-		if (S_ISDIR(sb.st_mode)) {
-			nfile = g_malloc0(strlen (filename) + 3);
-			sprintf(nfile, "%s/.", filename);
-			gtk_file_selection_set_filename(GTK_FILE_SELECTION(
-				w->open_fileselector), nfile);
-			g_free(nfile);
-			return TRUE;
-		}
-
-		curdoc = gE_document_current(w);
-		if (curdoc->filename || curdoc->changed)
-			gE_document_new(data->window);
-
-		nfile = g_strdup(filename);
-		gE_file_open(data->window, gE_document_current(w), nfile);
-	}
-	if (GTK_WIDGET_VISIBLE(fs))
-		gtk_widget_hide (GTK_WIDGET(fs));
-
-	return TRUE;
-} /* file_open_ok_sel */
-
-/*
- * file save-as callback : user selects "Ok"
- *
- * data->temp1 must be the file saveas dialog box
- */
-gint
-file_saveas_ok_sel(GtkWidget *w, gE_data *data)
-{
-	char *fname;
-	GtkWidget *safs;
-
-	g_assert(data != NULL);
-	safs = (GtkWidget *)(data->temp1);
-	g_assert(safs != NULL);
-
-	fname = gtk_file_selection_get_filename(GTK_FILE_SELECTION(safs));
-	if (fname != NULL) {
-		if (gE_file_save(data->window,
-			gE_document_current(data->window), fname) == 0) {
-
-			gtk_widget_destroy(data->temp1);
-			data->temp1 = NULL;
-			data->temp2 = NULL;
-			data->flag = TRUE;	/* indicate saved */
-		} else
-			data->flag = FALSE;	/* indicate not saved */
-	}
-
-	return TRUE;
-} /* file_saveas_ok_sel */
-
-
-/*
- * file open callback : user selects "Cancel"
- */
-static gint
-file_cancel_sel (GtkWidget *w, GtkFileSelection *fs)
-{
-  if (GTK_WIDGET_VISIBLE(fs))
-    gtk_widget_hide (GTK_WIDGET(fs));
-  return TRUE;
-}
-
-
-/*
- * file selection dialog callback
- */
-static gint
-file_sel_destroy (GtkWidget *w, GtkFileSelection *fs)
-{
-	fs = NULL;
-	return TRUE;
-}
-
-
 /* --- Notebook Tab Stuff --- */
 
+   
 void
 tab_top_cb(GtkWidget *widget, gpointer cbwindow)
 {
 	gE_window *w = (gE_window *)cbwindow;
 
-	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(w->notebook), GTK_POS_TOP);
-	w->tab_pos = GTK_POS_TOP;
+	mdi->tab_pos = GTK_POS_TOP;
+	settings->tab_pos = GTK_POS_TOP;
 }
 
 
@@ -298,8 +219,8 @@ tab_bot_cb(GtkWidget *widget, gpointer cbwindow)
 {
 	gE_window *w = (gE_window *)cbwindow;
 
-	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(w->notebook), GTK_POS_BOTTOM);
-	w->tab_pos = GTK_POS_BOTTOM;
+	mdi->tab_pos =  GTK_POS_BOTTOM;
+	settings->tab_pos = GTK_POS_BOTTOM;
 }
 
 void
@@ -307,8 +228,8 @@ tab_lef_cb(GtkWidget *widget, gpointer cbwindow)
 {
 	gE_window *w = (gE_window *)cbwindow;
 
-	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(w->notebook), GTK_POS_LEFT);
-	w->tab_pos = GTK_POS_LEFT;
+	mdi->tab_pos =  GTK_POS_LEFT;
+	settings->tab_pos = GTK_POS_LEFT;
 }
 
 void
@@ -316,10 +237,10 @@ tab_rgt_cb(GtkWidget *widget, gpointer cbwindow)
 {
 	gE_window *w = (gE_window *)cbwindow;
 
-	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(w->notebook), GTK_POS_RIGHT);
-	w->tab_pos = GTK_POS_RIGHT;
+	mdi->tab_pos =  GTK_POS_RIGHT;
+	settings->tab_pos = GTK_POS_RIGHT;
 }
-
+/*
 void
 tab_toggle_cb(GtkWidget *widget, gpointer cbwindow)
 {
@@ -328,8 +249,69 @@ tab_toggle_cb(GtkWidget *widget, gpointer cbwindow)
 	w->show_tabs = !w->show_tabs;
 	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(w->notebook), w->show_tabs);
 }
+*/
 
+/* Scrollbar Options */
+void
+scrollbar_none_cb (GtkWidget *widget, gpointer cbdata)
+{
+int c, w;
 
+	for (c = 0; c < g_list_length (mdi->children); c++)
+  	   {
+	     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (
+	        ((gE_document *) g_list_nth_data (mdi->children, c))->scrwindow[0]),
+				      GTK_POLICY_NEVER,
+				      GTK_POLICY_NEVER);
+
+	     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (
+	        ((gE_document *) g_list_nth_data (mdi->children, c))->scrwindow[1]),
+				      GTK_POLICY_NEVER,
+				      GTK_POLICY_NEVER);
+           }
+         settings->scrollbar = GTK_POLICY_NEVER;
+}
+
+void
+scrollbar_always_cb (GtkWidget *widget, gpointer cbdata)
+{
+int c, w;
+
+	for (c = 0; c < g_list_length (mdi->children); c++)
+  	   {
+	     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (
+	        ((gE_document *) g_list_nth_data (mdi->children, c))->scrwindow[0]),
+				      GTK_POLICY_NEVER,
+				      GTK_POLICY_ALWAYS);
+
+	     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (
+	        ((gE_document *) g_list_nth_data (mdi->children, c))->scrwindow[1]),
+				      GTK_POLICY_NEVER,
+				      GTK_POLICY_ALWAYS);
+           }
+         settings->scrollbar = GTK_POLICY_ALWAYS;
+
+}
+
+void
+scrollbar_auto_cb (GtkWidget *widget, gpointer cbdata)
+{
+int c, w;
+
+	for (c = 0; c < g_list_length (mdi->children); c++)
+  	   {
+	     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (
+	        ((gE_document *) g_list_nth_data (mdi->children, c))->scrwindow[0]),
+				      GTK_POLICY_NEVER,
+				      GTK_POLICY_AUTOMATIC);
+
+	     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (
+	        ((gE_document *) g_list_nth_data (mdi->children, c))->scrwindow[1]),
+				      GTK_POLICY_NEVER,
+				      GTK_POLICY_AUTOMATIC);
+           }
+         settings->scrollbar = GTK_POLICY_NEVER;
+}
 
 /* ---- Auto-indent Callback(s) --- */
 
@@ -338,12 +320,12 @@ auto_indent_toggle_cb(GtkWidget *w, gpointer cbdata)
 {
 	gE_data *data = (gE_data *)cbdata;
 
-	gE_window_set_auto_indent (data->window, !data->window->auto_indent);
+	gE_window_set_auto_indent (!settings->auto_indent);
 }
 
 gint
 auto_indent_cb(GtkWidget *text, char *insertion_text, int length,
-	int *pos, gE_window *window)
+	int *pos, gpointer cbdata)
 {
 	int i, newlines, newline_1 = 0;
 	gchar *buffer, *whitespace;
@@ -351,14 +333,14 @@ auto_indent_cb(GtkWidget *text, char *insertion_text, int length,
 	
 	data = g_malloc0 (sizeof (gE_data));
 	data->temp2 = text;
-	data->window = window;
-	line_pos_cb(NULL, data);
+	/*data->window = window;
+	line_pos_cb(NULL, data);*/
 
 	if ((length != 1) || (insertion_text[0] != '\n'))
 		return FALSE;
 	if (gtk_text_get_length (GTK_TEXT (text)) <=1)
 		return FALSE;
-	if (!data->window->auto_indent)
+	if (!settings->auto_indent)
 		return FALSE;
 
 	newlines = 0;
@@ -411,7 +393,7 @@ auto_indent_cb(GtkWidget *text, char *insertion_text, int length,
 	
 	g_free (whitespace);
 	data->temp2 = text;
-	line_pos_cb(NULL, data);
+	/*line_pos_cb(NULL, data);*/
 	return TRUE;
 }
 
@@ -420,30 +402,38 @@ static void
 line_pos_cb(GtkWidget *w, gE_data *data)
 {
 	static char col [32];
-	GtkWidget *text = data->temp2;
-	int x;
-
-	sprintf (col, "%d", GTK_TEXT(text)->cursor_pos_x/7);
+	GtkWidget *label;
+	GnomeApp *app;
+	/*GtkWidget *text = data->temp2;*/
+/*	gint x, y;*/
 	
-	gtk_label_set (GTK_LABEL(data->window->col_label), col);
+	app = gnome_mdi_get_active_window  (mdi);
+	
+	sprintf (col, "Column:\t%d",
+	 GTK_TEXT(gE_document_current()->text)->cursor_pos_x/7);
+	
+	label = gnome_dock_item_get_child (gnome_app_get_dock_item_by_name (app, "Column"));
+	
+	gtk_label_set (GTK_LABEL(label), col);
 
 }
 
 
-gint gE_event_button_press (GtkWidget *w, GdkEventButton *event, gE_window *window)
+gint gE_event_button_press (GtkWidget *w, GdkEventButton *event)
 {
 	gE_data *data;
 	data = g_malloc0 (sizeof (gE_data));
-	data->temp2 = w;
-	data->window = window;
+/*	data->temp2 = w;
+	data->window = window;*/
 	line_pos_cb(NULL, data);
+#ifdef DEBUG
+	g_print ("you pressed a button\n");
+#endif
 	return FALSE;
 }
 
 /* --- Drag and Drop Callback(s) --- */
 
-/* This is a modified routine from gnumeric. */
-
 void
 filenames_dropped (GtkWidget * widget,
                    GdkDragContext   *context,
@@ -451,16 +441,17 @@ filenames_dropped (GtkWidget * widget,
                    gint              y,
                    GtkSelectionData *selection_data,
                    guint             info,
-                   guint             time,
-                   gE_window        *window)
+                   guint             time)
 {
 	GList *names, *tmp_list;
+	gE_document *doc;
 
 	names = gnome_uri_list_extract_filenames ((char *)selection_data->data);
 	tmp_list = names;
 
 	while (tmp_list) {
-		gE_document_new_with_file (window, tmp_list->data);
+		doc = gE_document_new_with_file ((gchar *)tmp_list->data);
+		
 		tmp_list = tmp_list->next;
 	}
 }
@@ -470,27 +461,16 @@ filenames_dropped (GtkWidget * widget,
 
 void file_new_cb (GtkWidget *widget, gpointer cbdata)
 {
-	gE_data *data = (gE_data *)cbdata;
-	gE_window *w;
 	gE_document *doc;
 
-	g_assert(data != NULL);
-	w = data->window;
-	g_assert(w != NULL);
-	gE_msgbar_set(w, MSGBAR_FILE_NEW);
-	gE_document_new(w);
-	doc = gE_document_current(w);
-
-	if (w->files_list_window)
-		flw_append_entry(w, doc,
-			g_list_length(GTK_NOTEBOOK(w->notebook)->children) - 1,
-			doc->filename);
+	gnome_app_flash (mdi->active_window, MSGBAR_FILE_NEW);
+	doc = gE_document_new();
 }
 
 
 void window_new_cb(GtkWidget *widget, gpointer cbdata)
 {
-	gE_window *window;
+/*	gE_window *window;
 	gE_data *data = (gE_data *)cbdata;
 
 	window = gE_window_new();
@@ -500,39 +480,120 @@ void window_new_cb(GtkWidget *widget, gpointer cbdata)
 	window->tab_pos = data->window->tab_pos;
 	window->have_toolbar = data->window->have_toolbar;
 
-	gE_get_settings (window);
+	gE_get_settings (window);*/
+	gnome_mdi_open_toplevel(mdi);
+	
 }
 
 
+/*
+ * file open callback : user selects "Ok"
+ */
+static void file_open_ok_sel(GtkWidget *widget, GtkFileSelection *files)
+{
+	gchar *filename;
+	gchar *nfile;
+	gchar *flash;
+	struct stat sb;
+	gE_document *doc;
+
+
+	filename = g_malloc (strlen (gtk_file_selection_get_filename (GTK_FILE_SELECTION(osel))) + 1);
+	filename = g_strdup (gtk_file_selection_get_filename(GTK_FILE_SELECTION(osel)));
+	gtk_file_selection_set_filename(GTK_FILE_SELECTION(osel),"");
+	
+	if (filename != NULL) 
+	  {
+		if (stat(filename, &sb) == -1)
+			return;
+
+		if (S_ISDIR(sb.st_mode)) 
+		  {
+			nfile = g_malloc0(strlen (filename) + 3);
+			sprintf(nfile, "%s/.", filename);
+			gtk_file_selection_set_filename(GTK_FILE_SELECTION(osel), nfile);
+			g_free(nfile);
+			return;
+		  }
+
+		 if (gE_document_current ())
+		   {
+		     doc = gE_document_current();
+		     
+		     if (doc->filename || doc->changed)
+		       doc = gE_document_new_with_file (filename);
+		     else
+		       gE_file_open (GE_DOCUMENT(doc), filename);
+		     
+		     gtk_widget_hide (GTK_WIDGET(osel));
+		     return;
+		   }
+		 else
+		   {
+		     doc = gE_document_new_with_file (filename);
+		     
+		     gtk_widget_hide (GTK_WIDGET(osel));
+		     return;
+		   }
+	
+		
+
+	  }
+	
+	gtk_widget_hide (GTK_WIDGET(osel));
+	return;
+	
+} /* file_open_ok_sel */
+
+/*
+ * file selection dialog callback
+ */
+static void
+file_sel_destroy (GtkWidget *w, GtkFileSelection *fs)
+{
+	gtk_widget_hide (w);
+		
+}
+
+/*
+ * file open callback : user selects "Cancel"
+ */
+static gint
+file_cancel_sel (GtkWidget *w, GtkFileSelection *fs)
+{
+  if (GTK_WIDGET_VISIBLE(fs))
+    gtk_widget_hide (GTK_WIDGET(fs));
+  return TRUE;
+}
+
 void file_open_cb(GtkWidget *widget, gpointer cbdata)
 {
-	gE_data *data = (gE_data *)cbdata;
-	gE_window *w;
+	
+	/*static GtkWidget *open_fileselector;*/
+	
+	if (osel == NULL)
+	  osel = gtk_file_selection_new(_("Open File..."));
+		
 
-	g_assert(data != NULL);
-	w = data->window;
-	g_assert(w != NULL);
+	gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION(osel));
+	
+	gtk_signal_connect(GTK_OBJECT(osel), "delete_event",
+			(GtkSignalFunc)file_sel_destroy, osel);
+			
+	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(osel)->ok_button), 
+				   "clicked", (GtkSignalFunc)file_open_ok_sel,
+				   osel);
+	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(osel)->cancel_button),
+				   "clicked", (GtkSignalFunc)file_cancel_sel,
+			       osel);
 
-	if (w->open_fileselector == NULL) {
-		w->open_fileselector = gtk_file_selection_new(_("Open File..."));
-		gtk_file_selection_hide_fileop_buttons(
-			GTK_FILE_SELECTION(w->open_fileselector));
-		gtk_signal_connect(GTK_OBJECT(w->open_fileselector), "destroy",
-			(GtkSignalFunc)file_sel_destroy, w->open_fileselector);
-		gtk_signal_connect(GTK_OBJECT(
-			GTK_FILE_SELECTION(w->open_fileselector)->ok_button), 
-			"clicked", (GtkSignalFunc)file_open_ok_sel, data);
-		gtk_signal_connect(GTK_OBJECT(
-			GTK_FILE_SELECTION(
-				w->open_fileselector)->cancel_button),
-			"clicked", (GtkSignalFunc)file_cancel_sel,
-			w->open_fileselector);
-	}
 
-	if (GTK_WIDGET_VISIBLE(w->open_fileselector))
+/*	if (GTK_WIDGET_VISIBLE(open_fs))
 		return;
-
-	gtk_widget_show(w->open_fileselector);
+*/
+	gtk_widget_show(osel);
+	
+	return;
 }
 
 
@@ -545,7 +606,7 @@ void file_open_cb(GtkWidget *widget, gpointer cbdata)
  * have to "close" the document in the original window without destroying the
  * actual contents.
  */
-void
+/*void		This function is defunct..
 file_open_in_new_win_cb(GtkWidget *widget, gpointer cbdata)
 {
 	gE_document *src_doc, *dest_doc;
@@ -555,10 +616,10 @@ file_open_in_new_win_cb(GtkWidget *widget, gpointer cbdata)
 	int pos = 0;
 	gchar *base;
 	
-	src_doc = gE_document_current (data->window);
+	src_doc = gE_document_current ();
 	buffer = gtk_editable_get_chars (GTK_EDITABLE (src_doc->text), 0, -1);
 	win = gE_window_new ();
-	dest_doc = gE_document_current (win);
+	dest_doc = gE_document_current ();
 	dest_doc->filename = g_strdup (src_doc->filename);
 
 	gtk_label_set (GTK_LABEL (dest_doc->tab_label), (const char *)g_basename (dest_doc->filename));
@@ -568,61 +629,92 @@ file_open_in_new_win_cb(GtkWidget *widget, gpointer cbdata)
 	close_doc_execute (src_doc, data);
 	g_free (buffer);
 }
+*/
 
-
-void
-file_save_cb(GtkWidget *widget, gpointer cbdata)
+void file_save_cb(GtkWidget *widget, gpointer cbdata)
 {
 	gchar *fname;
-	gE_data *data = (gE_data *)cbdata;
+	gE_document *doc;
 
-	g_assert(data != NULL);
-	g_assert(data->window != NULL);
- 	fname = gE_document_current(data->window)->filename;
-	if (fname == NULL)
-		file_save_as_cb(NULL, data);
-	else
-	 if ((gE_file_save(data->window, gE_document_current(data->window),
-	               gE_document_current(data->window)->filename)) != 0)
-	   {
-	gE_msgbar_set(data->window, _("Read only file!"));
-	file_save_as_cb(NULL, data);
-        }
+	if (gE_document_current())
+	  {
+	    doc = gE_document_current();
+	    if (doc->changed)
+	      {
+ 	        fname = doc->filename;
 
+ 	    
+	        if (fname == NULL)
+	           file_save_as_cb(widget, NULL);
+	        else
+	           if ((gE_file_save(doc, doc->filename)) != 0)
+	             {
+		       gnome_app_flash (mdi->active_window, _("Read only file!"));
+		       file_save_as_cb(widget, NULL);
+        	     }
+              }
+          }
 }
 
-void
-file_save_as_cb(GtkWidget *widget, gpointer cbdata)
+
+/*
+ * file save-as callback : user selects "Ok"
+ *
+ * data->temp1 must be the file saveas dialog box
+ */
+static void file_saveas_ok_sel(GtkWidget *w, gE_data *data)
 {
-	GtkWidget *safs;
-	gE_data *data = (gE_data *)cbdata;
+	gchar *fname = gtk_file_selection_get_filename (GTK_FILE_SELECTION(ssel));
+	gE_document *doc;
 
-	g_assert(data != NULL);
-
-	safs = gtk_file_selection_new(_("Save As..."));
-
-	data->temp1 = safs;
-	gtk_signal_connect(GTK_OBJECT(safs), "destroy",
-		(GtkSignalFunc)file_saveas_destroy, safs);
-	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(safs)->ok_button),
-		"clicked", (GtkSignalFunc)file_saveas_ok_sel, data);
-	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(safs)->cancel_button),
-		"clicked", (GtkSignalFunc)file_saveas_destroy, safs);
-
-	gtk_widget_show(safs);
-}
+	if (mdi->active_child == NULL)
+	  return;
+	
+	doc = gE_document_current();
+	
+	if (fname) 
+	  {
+	    if (gE_file_save(doc, fname) != 0) 
+	      gnome_app_flash (mdi->active_window, _("Error saving file!"));
+	  }
 
+	gtk_widget_destroy (GTK_WIDGET (ssel));
+	ssel = NULL;
+} /* file_saveas_ok_sel */
 
 /*
  * destroy the "save as" dialog box
  */
 static gint
-file_saveas_destroy(GtkWidget *w, gpointer cbdata)
+file_saveas_destroy(GtkWidget *w, GtkWidget **sel)
 {
-	gtk_widget_destroy((GtkWidget *)cbdata);
+	gtk_widget_destroy(*sel);
+	*sel = NULL;
+	
 	return TRUE;
 }
 
+void
+file_save_as_cb(GtkWidget *widget, gpointer cbdata)
+{
+
+	ssel = gtk_file_selection_new(_("Save As..."));
+
+/*	gtk_signal_connect(GTK_OBJECT(safs), "destroy",
+		(GtkSignalFunc)file_saveas_destroy, safs);*/
+		
+	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(ssel)->ok_button),
+				   "clicked", (GtkSignalFunc)file_saveas_ok_sel, 
+				   NULL);
+	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(ssel)->cancel_button),
+				"clicked", (GtkSignalFunc)file_saveas_destroy, 
+				&ssel);
+
+	gtk_widget_show(ssel);
+}
+
+
+
 
 /*
  * file close callback (used from menus.c)
@@ -630,19 +722,88 @@ file_saveas_destroy(GtkWidget *w, gpointer cbdata)
 void
 file_close_cb(GtkWidget *widget, gpointer cbdata)
 {
-	gE_data *data = (gE_data *)cbdata;
+/*	gE_data *data = (gE_data *)cbdata;
 
 	g_assert(data != NULL);
-	close_doc_common(data);
+	close_doc_common(data);*/
+	
+	if (mdi->active_child == NULL)
+	  return;
+	
+	if (gnome_mdi_remove_child (mdi, mdi->active_child, FALSE))
+	  {
+	    if (mdi->active_child == NULL)
+	      {
+	        if (!settings->close_doc)
+	          gE_document_new ();
+	        else
+	          g_print ("hola!\n");
+	      }
+	  }
 }
 
 
+gint file_revert_do (gE_document *doc)
+{
+	GnomeMessageBox *msgbox;
+	gchar msg[80];
+	gint ret;
+
+	sprintf(msg, _("Are you sure you wish to revert all changes?"));
+	
+
+	msgbox = GNOME_MESSAGE_BOX (gnome_message_box_new (
+	    							  msg,
+	    							  GNOME_MESSAGE_BOX_QUESTION,
+	    							  GNOME_STOCK_BUTTON_YES,
+	    							  GNOME_STOCK_BUTTON_NO,
+	    							  NULL));
+	gnome_dialog_set_default (GNOME_DIALOG (msgbox), 2);
+	ret = gnome_dialog_run_and_close (GNOME_DIALOG (msgbox));
+	    	    
+	switch (ret)
+	      {
+	        case 0:
+	                 gE_file_open (doc, doc->filename);
+	                 return TRUE;
+	        case 1:
+	                 return FALSE;
+	        default:
+	                 return FALSE;
+	      }
+	      
+
+}
+
+/* File revertion callback */
+void file_revert_cb (GtkWidget *widget, gpointer cbdata)
+{
+	gE_document *doc;
+	
+	if (gE_document_current ())
+	  {
+	    doc = gE_document_current ();
+	    
+	    if (doc->filename)
+	      if (doc->changed)
+	        {
+	          if ((file_revert_do (doc)) == 0)
+	            return;
+	        }
+	      else
+	        gnome_app_flash (mdi->active_window, _("Document Unchanged..."));
+	    else
+	      gnome_app_flash (mdi->active_window, _("Document Unsaved..."));
+	  }
+	
+}
+
 /*
  * common routine for closing a file.  will prompt for saving if the
  * file was changed.
  *
  * data->flag is set to TRUE if file closed
- */
+ *//*
 static void
 close_doc_common(gE_data *data)
 {
@@ -650,19 +811,19 @@ close_doc_common(gE_data *data)
 
 	g_assert(data != NULL);
 	g_assert(data->window != NULL);
-	doc = gE_document_current(data->window);
+	doc = gE_document_current();
 	if (doc->changed)
 		popup_close_verify(doc, data);
 	else {
 		close_doc_execute(NULL, data);
-		data->flag = TRUE;	/* indicate closed */
+		data->flag = TRUE;	// indicate closed 
 	}
-} /* close_doc_common */
+} *//* close_doc_common */
 
 
 /*
  * actually close the document.
- */
+ *//*
 void
 close_doc_execute(gE_document *opt_doc, gpointer cbdata)
 {
@@ -679,26 +840,26 @@ close_doc_execute(gE_document *opt_doc, gpointer cbdata)
 	g_assert(w != NULL);
 	nb = GTK_NOTEBOOK(w->notebook);
 	g_assert(nb != NULL);
-	/*
-	 * Provide the option to pass the specific document as an argument
-	 * instead of always going with the current document - needed for
-	 * the plugins api...
-	 */
-	doc = (opt_doc == NULL) ? gE_document_current(w) : opt_doc;
+	//
+	// Provide the option to pass the specific document as an argument
+	// instead of always going with the current document - needed for
+	// the plugins api...
+	//
+	doc = (opt_doc == NULL) ? gE_document_current() : opt_doc;
 	g_assert(doc != NULL);
 
-	/* if all we have is a blank, Untitled doc, then return immediately */
+	// if all we have is a blank, Untitled doc, then return immediately 
 	if (!doc->changed && g_list_length(nb->children) == 1 &&
 		doc->filename == NULL)
 		return;
 
-	/* Remove document from our hash tables */
+	// Remove document from our hash tables 
 	ptr = g_hash_table_lookup(doc_pointer_to_int, doc);
 	g_hash_table_remove(doc_int_to_pointer, ptr);
 	g_hash_table_remove(doc_pointer_to_int, doc);
 	g_free (ptr);
 
-	/* remove notebook entry and item from document list */
+	// remove notebook entry and item from document list //
 	num = gtk_notebook_current_page(nb);
 	gtk_notebook_remove_page(nb, num);
 	w->documents = g_list_remove(w->documents, doc);
@@ -708,20 +869,20 @@ close_doc_execute(gE_document *opt_doc, gpointer cbdata)
 		g_free(doc->sb);
 	g_free(doc);
 
-	/* if files list window present, remove corresponding entry */
+	// if files list window present, remove corresponding entry 
 	flw_remove_entry(w, num);
 
-	/* echo message to user */
+	// echo message to user 
 	gE_msgbar_set(w, MSGBAR_FILE_CLOSED);
 
 	num = g_list_length(nb->children);
 	numdoc = g_list_length(w->documents);
 	g_assert(num == numdoc);
 
-	/*
-	 * we always have at least one document (e.g., "Untitled").
-	 * so if we just closed the last document, create "Untitled".
-	 */
+	//
+	// we always have at least one document (e.g., "Untitled").
+	// so if we just closed the last document, create "Untitled".
+	//
 	if (num < 1) {
 		g_list_free(w->documents);
 		w->documents = NULL;
@@ -730,117 +891,19 @@ close_doc_execute(gE_document *opt_doc, gpointer cbdata)
 			flw_append_entry(w, doc,
 				g_list_length(nb->children) - 1, NULL);
 	}
-	/* Set the title of the window to Current Document - GEDIT_ID */
+	// Set the title of the window to Current Document - GEDIT_ID 
 	
 	title = g_malloc0(strlen(GEDIT_ID) +
-		strlen(GTK_LABEL(gE_document_current(w)->tab_label)->label) + 4);
+		strlen(GTK_LABEL(gE_document_current()->tab_label)->label) + 4);
 	sprintf(title, "%s - %s",
-	 GTK_LABEL(gE_document_current(w)->tab_label)->label,
+	 GTK_LABEL(gE_document_current()->tab_label)->label,
 	 GEDIT_ID);
 	gtk_window_set_title(GTK_WINDOW(w->window), title);
 	g_free(title);
 
-} /* close_doc_execute */
+} *//* close_doc_execute */
 
 
-/*
- * close all documents in invoking window
- */
-void
-file_close_all_cb(GtkWidget *widget, gpointer cbdata)
-{
-	gE_data *data = (gE_data *)cbdata;
-	GtkNotebook *nb;
-	int num, i;
-	gboolean allclosed = TRUE;
-
-	g_assert(data != NULL);
-	g_assert(data->window != NULL);
-	nb = GTK_NOTEBOOK(data->window->notebook);
-	g_assert(nb != NULL);
-	num = g_list_length(nb->children);
-	g_assert(num > 0);
-	/*gtk_widget_hide(data->window->notebook);*/
-
-	for (i = 0; i < num; i++) {
-		close_doc_common(data);
-
-		/* if a file was not closed, then all files were not closed */
-		if (!data->flag) {
-			allclosed = FALSE;
-			break;
-		}
-	}
-
-	/*gtk_widget_show(data->window->notebook);*/
-
-	data->flag = allclosed;
-
-	if (i == num) {
-		g_assert(allclosed == TRUE);
-		gE_msgbar_set(data->window, MSGBAR_FILE_CLOSED_ALL);
-	}
-} /* file_close_all_cb */
-
-
-/*
- * closes gEdit window by closing all documents.  only if all documents are
- * closed will the window actually go away.
- */
-void
-window_close_cb(GtkWidget *widget, gpointer cbdata)
-{
-	gE_data *data = (gE_data *)cbdata;
-
-	g_assert(data != NULL);
-	g_assert(data->window != NULL);
-	/*gtk_widget_hide(data->window->window);*/
-	flw_destroy(NULL, data);
-
-	data->flag = FALSE;	/* use flag to indicate all files closed */
-	file_close_all_cb(widget, cbdata);
-	/*gtk_widget_hide(data->window->window);*/
-
-	if (data->flag) {
-		gE_msgbar_clear((gpointer)(data->window));
-
-		close_window_common(data->window);	/* may not return */
-
-		data->window = g_list_nth_data(window_list, 0);
-		/*gtk_widget_hide(data->window->window);*/
-	} else
-		gtk_widget_show(data->window->window);
-}
-
-
-/*
- * actually close the window.  exits if last window is closed.
- */
-static void
-close_window_common(gE_window *w)
-{
-	gint *ptr;
-	g_assert(w != NULL);
-	window_list = g_list_remove(window_list, (gpointer)w);
-
-	ptr = g_hash_table_lookup(win_pointer_to_int, w);
-	g_hash_table_remove(win_int_to_pointer, ptr);
-	g_hash_table_remove(win_pointer_to_int, w);
-	g_free (ptr);
-	
-	if (w->files_list_window)
-		gtk_widget_destroy(w->files_list_window);
-	gtk_widget_destroy(w->window);
-	gE_save_settings (w, w);
-
-	g_free(w->search);
-	g_free(w);
-
-	if (window_list == NULL)
-	{
-		gtk_exit(0);
-	}
-}
 
 
 /*
@@ -849,18 +912,13 @@ close_window_common(gE_window *w)
 void
 file_quit_cb(GtkWidget *widget, gpointer cbdata)
 {
-	gE_data *data = (gE_data *)cbdata;
-
-	g_assert(data != NULL);
-	
 	plugin_save_list();
+
+	if (gnome_mdi_remove_all (mdi, FALSE))
+	  gtk_object_destroy (GTK_OBJECT (mdi));
+	else
+	  return;
 	
-	while (window_list) {
-		data->window = g_list_nth_data(window_list, 0);
-		window_close_cb(widget, data);
-		if (data->flag == FALSE)	/* cancelled by user */
-			return;
-	}
 	gtk_exit(0);	/* should not reach here */
 }
 
@@ -872,14 +930,11 @@ edit_cut_cb(GtkWidget *widget, gpointer cbdata)
 {
 	gE_data *data = (gE_data *)cbdata;
 
-#if (GTK_MAJOR_VERSION==1) && (GTK_MINOR_VERSION==1)
-	gtk_editable_cut_clipboard(
-		GTK_EDITABLE(gE_document_current(data->window)->text));
-#else
 	gtk_editable_cut_clipboard(GTK_EDITABLE(
-		gE_document_current(data->window)->text));
-#endif
-	gE_msgbar_set(data->window, MSGBAR_CUT);
+		gE_document_current()->text));
+
+	/*gE_msgbar_set(data->window, MSGBAR_CUT);*/
+	gnome_app_flash (mdi->active_window, MSGBAR_CUT);
 }
 
 void
@@ -888,8 +943,9 @@ edit_copy_cb(GtkWidget *widget, gpointer cbdata)
 	gE_data *data = (gE_data *)cbdata;
 
 	gtk_editable_copy_clipboard(
-		GTK_EDITABLE(gE_document_current(data->window)->text));
-	gE_msgbar_set(data->window, MSGBAR_COPY);
+		GTK_EDITABLE(gE_document_current()->text));
+/*	gE_msgbar_set(data->window, MSGBAR_COPY);*/
+	gnome_app_flash (mdi->active_window, MSGBAR_COPY);
 }
 	
 void
@@ -898,9 +954,10 @@ edit_paste_cb(GtkWidget *widget, gpointer cbdata)
 	gE_data *data = (gE_data *)cbdata;
 
 	gtk_editable_paste_clipboard(
-		GTK_EDITABLE(gE_document_current(data->window)->text));
+		GTK_EDITABLE(gE_document_current()->text));
 
-	gE_msgbar_set(data->window, MSGBAR_PASTE);
+/*	gE_msgbar_set(data->window, MSGBAR_PASTE);*/
+	gnome_app_flash (mdi->active_window, MSGBAR_PASTE);
 }
 
 void
@@ -909,10 +966,11 @@ edit_selall_cb(GtkWidget *widget, gpointer cbdata)
 	gE_data *data = (gE_data *)cbdata;
 
 	gtk_editable_select_region(
-		GTK_EDITABLE(gE_document_current(data->window)->text), 0,
+		GTK_EDITABLE(gE_document_current()->text), 0,
 		gtk_text_get_length(
-			GTK_TEXT(gE_document_current(data->window)->text)));
-	gE_msgbar_set(data->window, MSGBAR_SELECT_ALL);
+			GTK_TEXT(gE_document_current()->text)));
+/*	gE_msgbar_set(data->window, MSGBAR_SELECT_ALL);*/
+	gnome_app_flash (mdi->active_window, MSGBAR_SELECT_ALL);
 }
 
 
@@ -972,7 +1030,7 @@ gnome_app_remove_menu_range (GnomeApp *app,
  * Should be called after each addition to the list 
  */
 
-void recent_update (gE_window *window)
+void recent_update (GnomeApp *app)
 {
 	GList *filelist = NULL;
 	GList *dirlist = NULL;
@@ -1023,22 +1081,21 @@ void recent_update (gE_window *window)
 	}
 	gnome_history_free_recently_used_list (gnome_recent_list);
 	
-	recent_update_menus (window, filelist);
+	recent_update_menus (app, filelist);
 }
 
 /* Actually updates the recent-used menu... */
 
 static void
-recent_update_menus (gE_window *window, GList *recent_files)
+recent_update_menus (GnomeApp *app, GList *recent_files)
 {
 	GnomeUIInfo *menu;
 	gE_data *data;
 	gchar *path;
 	int i;
-	
-	if (window->num_recent > 0)
-		gnome_app_remove_menu_range (GNOME_APP (window->window), 
-			"_File/", 5, window->num_recent + 1);
+
+	if (settings->num_recent)
+	  gnome_app_remove_menu_range (app, _("_File/"), 6, settings->num_recent + 1);
 
 	if (recent_files == NULL)
 		return;
@@ -1052,7 +1109,7 @@ recent_update_menus (gE_window *window, GList *recent_files)
 	menu->type = GNOME_APP_UI_SEPARATOR;
 
 	(menu + 1)->type = GNOME_APP_UI_ENDOFINFO;
-	gnome_app_insert_menus (GNOME_APP(window->window), path, menu);
+	gnome_app_insert_menus (GNOME_APP(app), path, menu);
 
 
 	for (i = g_list_length (recent_files) - 1; i >= 0;  i--)
@@ -1061,7 +1118,7 @@ recent_update_menus (gE_window *window, GList *recent_files)
 	
 		data = g_malloc0 (sizeof (gE_data));
 		data->temp1 = g_strdup (g_list_nth_data (recent_files, i));
-		data->window = window;
+		/*data->window = window;*/
 		menu->label = g_new (gchar, 
 			strlen (g_list_nth_data (recent_files, i)) + 5);
 		sprintf (menu->label, "_%i. %s", i+1, (gchar*)g_list_nth_data (recent_files, i));
@@ -1076,10 +1133,10 @@ recent_update_menus (gE_window *window, GList *recent_files)
 
 		(menu + 1)->type = GNOME_APP_UI_ENDOFINFO;
 	
-		gnome_app_insert_menus_with_data (GNOME_APP(window->window), path, menu, data);
+		gnome_app_insert_menus (GNOME_APP(app), path, menu);
 		g_free (g_list_nth_data (recent_files, i));
 	}
-	window->num_recent = g_list_length (recent_files);
+	settings->num_recent = g_list_length (recent_files);
 	g_list_free (recent_files);
 
 
@@ -1088,10 +1145,17 @@ recent_update_menus (gE_window *window, GList *recent_files)
 static void
 recent_cb(GtkWidget *w, gE_data *data)
 {
-	gE_document *doc = gE_document_current (data->window);
-	if (doc->filename != NULL || doc->changed != 0)
-		gE_document_new (data->window);
-	gE_file_open (data->window, gE_document_current (data->window), data->temp1);
+	gE_document *doc;
+	
+	if ((doc = gE_document_current ()))
+	  {
+	    if (doc->filename || doc->changed)
+	      doc = gE_document_new_with_file (data->temp1);
+	    else		
+	      gE_file_open (doc, data->temp1);
+	  }
+	else
+	  doc = gE_document_new_with_file (data->temp1);
 }
 
 
@@ -1106,6 +1170,18 @@ doc_insert_text_cb(GtkWidget *editable, char *insertion_text, int length,
 	GtkWidget *significant_other;
 	gchar *buffer;
 	gint position = *pos;
+	gint n;
+	gE_document *temp;
+	GnomeMDIChild *child;
+	/*GnomeMDIChild *temp = NULL;*/
+	gE_data *data;
+	GtkWidget *text;
+	GList *view;
+
+	data = g_malloc0 (sizeof (gE_data));
+	line_pos_cb(NULL, data);
+	
+	g_free (data);
 	
 	if (!doc->split_screen)
 		return;
@@ -1116,6 +1192,7 @@ doc_insert_text_cb(GtkWidget *editable, char *insertion_text, int length,
 		return;
 	}
 	
+	
 	if (editable == doc->text)
 		significant_other = doc->split_screen;
 	else if (editable == doc->split_screen)
@@ -1125,6 +1202,31 @@ doc_insert_text_cb(GtkWidget *editable, char *insertion_text, int length,
 	
 	doc->flag = significant_other;	
 	buffer = g_strdup (insertion_text);
+
+/*	FIXME : This looks correct, but it isn't... I can't figure why it isnt working properly
+		( * - denotes comment, cant have comemts within comments )
+	child = GNOME_MDI_CHILD (doc);
+	view = child->views;
+	
+	while (view)
+	   {
+	     g_print ("doc_insert_text: n = %d views = %d\n",n, g_list_length (GNOME_MDI_CHILD (doc)->views));
+	     temp = (gE_document *)view->data;
+g_warning ("temp* has been set..");
+
+	     
+	     *gtk_text_freeze (GTK_TEXT(GE_DOCUMENT(temp)->text)); *
+	     gtk_text_freeze (GTK_TEXT(temp->text));
+g_warning ("temp->text has been frozen..");	     
+	    * gtk_editable_insert_text (GTK_EDITABLE(GE_DOCUMENT(temp)->text), buffer, length, &position);*
+	    gtk_editable_insert_text (GTK_EDITABLE(temp->text), buffer, length, &position);
+	     
+	    * gtk_text_thaw (GTK_TEXT(GE_DOCUMENT(temp)->text));*
+	    gtk_text_thaw (GTK_TEXT(temp->text));
+	    
+	    view = g_list_next (view);
+	   }
+*/	   
 	gtk_text_freeze (GTK_TEXT (significant_other));
 	gtk_editable_insert_text (GTK_EDITABLE (significant_other), buffer, length, &position);
 	gtk_text_thaw (GTK_TEXT (significant_other));
@@ -1137,7 +1239,13 @@ doc_delete_text_cb(GtkWidget *editable, int start_pos, int end_pos,
 	gE_document *doc)
 {
 	GtkWidget *significant_other;
+	gE_data *data;
+
+	data = g_malloc0 (sizeof (gE_data));
+	line_pos_cb(NULL, data);
 	
+	g_free (data);
+		
 	if (!doc->split_screen)
 		return;
 
@@ -1160,9 +1268,9 @@ doc_delete_text_cb(GtkWidget *editable, int start_pos, int end_pos,
 	gtk_text_thaw (GTK_TEXT (significant_other));
 }
 
-void options_toggle_split_screen_cb (GtkWidget *widget, gE_window *window)
+void options_toggle_split_screen_cb (GtkWidget *widget, gpointer data)
 {
-	gE_document *doc = gE_document_current (window);
+	gE_document *doc = gE_document_current ();
 	gint visible;
 
 	if (!doc->split_parent)
@@ -1173,25 +1281,25 @@ void options_toggle_split_screen_cb (GtkWidget *widget, gE_window *window)
 }
 
 
-void options_toggle_read_only_cb (GtkWidget *widget, gE_window *window)
+void options_toggle_read_only_cb (GtkWidget *widget, gpointer data)
 {
-	gE_document *doc = gE_document_current (window);
+	gE_document *doc = gE_document_current ();
 	gE_document_set_read_only (doc, !doc->read_only);
 }
 
-void options_toggle_word_wrap_cb (GtkWidget *widget, gE_window *window)
+void options_toggle_word_wrap_cb (GtkWidget *widget, gpointer data)
 {
-	gE_document *doc = gE_document_current (window);
+	gE_document *doc = gE_document_current ();
 	gE_document_set_word_wrap (doc, !doc->word_wrap);
 }
 
-void options_toggle_line_wrap_cb (GtkWidget *widget, gE_window *window)
+void options_toggle_line_wrap_cb (GtkWidget *widget, gpointer data)
 {
-	gE_document *doc = gE_document_current (window);
+	gE_document *doc = gE_document_current ();
 	gE_document_set_line_wrap (doc, !doc->line_wrap);
 }
 
-void options_toggle_status_bar_cb (GtkWidget *w, gE_window *window)
+void options_toggle_status_bar_cb (GtkWidget *w, gpointer data)
 {
-	gE_window_set_status_bar (window, !window->show_status);
+	gE_window_set_status_bar (!settings->show_status);
 }
