@@ -30,6 +30,7 @@
 #include "gE_prefs_box.h"
 #include "gE_document.h"
 #include "gE_plugin_api.h"
+#include "gE_mdi.h"
 
 typedef struct _gE_prefs_data {
 	GnomePropertyBox *pbox;
@@ -54,6 +55,25 @@ typedef struct _gE_prefs_data {
 	GtkWidget *plugins_toggle;
 	gE_data *gData;
 	
+	/* MDI Settings */
+	GtkRadioButton *mdi_type [NUM_MDI_MODES];
+	GSList *mdi_list;
+	
+	/* Window Settings */
+	GtkWidget *cur;
+	GtkWidget *preW;
+	GtkWidget *preH;
+	gchar *curW;
+	gchar *curH;
+	
+	/* Doc Settings */
+	/* Stuff like Autosave would go here.. if autosave
+	 * was actually implemented ;) */
+	/* Should print stuff go in here too? hmm.. */
+	GtkWidget *DButton1;
+	GtkWidget *DButton2;
+	
+	
 	/* Toolbar Settings */
 	/* Hmm, dunno... */
 	
@@ -63,11 +83,28 @@ typedef struct _gE_prefs_data {
 
 static gE_prefs_data *prefs;
 GList *plugin_list;
-plugin_callback_struct pl_callbacks;
+/*plugin_callback_struct pl_callbacks;*/
+extern GList *plugins;
+
+guint mdi_type [NUM_MDI_MODES] = {
+	GNOME_MDI_DEFAULT_MODE,
+	GNOME_MDI_NOTEBOOK,
+	GNOME_MDI_TOPLEVEL,
+	GNOME_MDI_MODAL
+};
+
+gchar *mdi_type_label [NUM_MDI_MODES] = {
+	N_("Default"),
+	N_("Notebook"),
+	N_("Toplevel"),
+	N_("Modal"),
+};
 
 void cancel()
 {
   gtk_widget_destroy (GTK_WIDGET (prefs->pbox));
+  g_free (prefs->curW);
+  g_free (prefs->curH);
   g_free(prefs);
   prefs = NULL;
 }
@@ -76,27 +113,45 @@ void gE_window_refresh(gE_window *w)
 {
 GtkStyle *style;
 gint i;
+/* FIXME: This function is basically borked right now... */
 
-    if (w->show_status == 0)
+/*FIXME    if (w->show_status == 0)
        gtk_widget_hide (GTK_WIDGET (w->statusbar)->parent);
      else
        gtk_widget_show (GTK_WIDGET (w->statusbar)->parent);
-       
-     /* if (w->splitscreen == TRUE) */
-       gE_document_set_split_screen (gE_document_current(w), (gint) w->splitscreen);
-    
+*/       
+/*      if (w->splitscreen == TRUE) 
+       gE_document_set_split_screen (gE_document_current(), (gint) w->splitscreen);
+  */  
+  
+  	gE_window_set_status_bar (settings->show_status);
+  
+  for (i = 0; i < NUM_MDI_MODES; i++)
+     if (GTK_TOGGLE_BUTTON (prefs->mdi_type[i])->active)
+       {
+         if (mdiMode != mdi_type[i])
+           {
+             mdiMode = mdi_type[i];
+             gnome_mdi_set_mode (mdi, mdiMode);
+           }
+         break;
+       }
+  
   style = gtk_style_new();
   gdk_font_unref (style->font);
-  style->font = gdk_font_load (w->font);
+  if (use_fontset)
+	  style->font = gdk_fontset_load (settings->font);
+  else
+	  style->font = gdk_font_load (settings->font);
   
   gtk_widget_push_style (style);    
-  for (i = 0; i < g_list_length (w->documents); i++)
+  for (i = 0; i < g_list_length (mdi->children); i++)
   {
   	gtk_widget_set_style(GTK_WIDGET(
-  		((gE_document *) g_list_nth_data (w->documents, i))->split_screen), style);
+  		((gE_document *) g_list_nth_data (mdi->children, i))->split_screen), style);
 
   	gtk_widget_set_style(GTK_WIDGET(
-  		((gE_document *) g_list_nth_data (w->documents, i))->text), style);
+  		((gE_document *) g_list_nth_data (mdi->children, i))->text), style);
   }
 
   gtk_widget_pop_style ();
@@ -108,18 +163,18 @@ void gE_apply(GnomePropertyBox *pbox, gint page, gE_data *data)
 {
   FILE *file;
   gchar *rc;
-
+  gint i;
 
   /* General Settings */
-  data->window->auto_indent = (GTK_TOGGLE_BUTTON (prefs->autoindent)->active);
-  data->window->show_status = (GTK_TOGGLE_BUTTON (prefs->status)->active);  
-  data->window->splitscreen = (GTK_TOGGLE_BUTTON (prefs->split)->active);
+  settings->auto_indent = (GTK_TOGGLE_BUTTON (prefs->autoindent)->active);
+  settings->show_status = (GTK_TOGGLE_BUTTON (prefs->status)->active);  
+  settings->splitscreen = (GTK_TOGGLE_BUTTON (prefs->split)->active);
 
   /* Print Settings */
-  data->window->print_cmd = g_strdup (gtk_entry_get_text (GTK_ENTRY(prefs->pcmd)));
+  settings->print_cmd = g_strdup (gtk_entry_get_text (GTK_ENTRY(prefs->pcmd)));
   
   /* Font Settings */
-    data->window->font = g_strdup (gtk_entry_get_text (GTK_ENTRY(prefs->font)));
+    settings->font = g_strdup (gtk_entry_get_text (GTK_ENTRY(prefs->font)));
   	if ((rc = gE_prefs_open_file ("gtkrc", "r")) == NULL)
 	{
 		printf ("Couldn't open gtk rc file for parsing.\n");
@@ -135,35 +190,73 @@ void gE_apply(GnomePropertyBox *pbox, gint page, gE_data *data)
 	fprintf(file, "#\n");
 	fprintf(file, "style \"text\"\n");
 	fprintf(file, "{\n");
-	fprintf(file, "  font = \"%s\"\n", data->window->font);
+	fprintf(file, "  font = \"%s\"\n", settings->font);
 	fprintf(file, "}\n");
 	fprintf(file, "widget_class \"*GtkText\" style \"text\"\n");
 	fclose(file);  
 
+  /* MDI Settings */
+  for (i = 0; i < NUM_MDI_MODES; i++)
+     if (GTK_TOGGLE_BUTTON (prefs->mdi_type[i])->active)
+       {
+         settings->mdi_mode = i;
+       }
+  
+  /* Window Settings */
+  settings->width = atoi (gtk_entry_get_text (GTK_ENTRY(prefs->preW)));
+  settings->height = atoi (gtk_entry_get_text (GTK_ENTRY(prefs->preH)));  
+  
+  /* Document Settings */
+  if (GTK_TOGGLE_BUTTON (prefs->DButton1)->active)
+    settings->close_doc = FALSE;
+  if (GTK_TOGGLE_BUTTON (prefs->DButton2)->active)
+    settings->close_doc = TRUE;
+  
   gE_window_refresh(data->window);
-  gE_save_settings(data->window, data->window);
+  gE_save_settings();
 }
 
 
 
 void get_prefs(gE_data *data)
 {
-  gint uP;
+  gint i;
+  gchar *tmp;
   
-  gtk_entry_set_text (GTK_ENTRY (prefs->pcmd), data->window->print_cmd);
-  gtk_entry_set_text (GTK_ENTRY (prefs->font), data->window->font);
+  gtk_entry_set_text (GTK_ENTRY (prefs->pcmd), settings->print_cmd);
+  gtk_entry_set_text (GTK_ENTRY (prefs->font), settings->font);
+
+  tmp = g_malloc (1);
+  sprintf (tmp, "%d", settings->width);
+  gtk_entry_set_text (GTK_ENTRY (prefs->preW), tmp);
+  sprintf (tmp, "%d", settings->height);
+  gtk_entry_set_text (GTK_ENTRY (prefs->preH), tmp);
+  g_free (tmp);
+
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (prefs->autoindent), 
-  					   data->window->auto_indent);
+  					   settings->auto_indent);
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (prefs->status),
-  					   data->window->show_status);
+  					   settings->show_status);
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (prefs->split),
-  					   data->window->splitscreen);
+  					   settings->splitscreen);
   					   
- 
+  if (!settings->close_doc)
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->DButton1), TRUE);
+  else
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->DButton2), TRUE);
+  
    if (!GTK_TOGGLE_BUTTON(prefs->plugins_toggle)->active)
      gtk_widget_set_sensitive (GTK_WIDGET (prefs->plugin_list), FALSE);
    else
      gtk_widget_set_sensitive (GTK_WIDGET (prefs->plugin_list), TRUE);
+   
+   for (i = 0; i < NUM_MDI_MODES; i++)
+      if (mdiMode == mdi_type[i]) 
+        {
+          gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->mdi_type[i]),
+          							 TRUE);
+          break;
+        }
 }
 
 /* General UI Stuff.. */
@@ -240,7 +333,7 @@ static GtkWidget *general_page_new()
 
 /* Print Stuf.. */
 
-static GtkWidget *print_page_new()
+static GtkWidget *doc_page_new()
 {
   GtkWidget *main_vbox, *vbox, *frame, *hbox;
   GtkWidget *label;
@@ -249,6 +342,33 @@ static GtkWidget *print_page_new()
   gtk_container_border_width (GTK_CONTAINER (main_vbox), 4);
   gtk_widget_show (main_vbox);
   
+  /* Document Closing stuffs */
+  frame = gtk_frame_new (_("Document Settings"));
+  gtk_box_pack_start (GTK_BOX (main_vbox), frame, TRUE, TRUE, 4);
+  gtk_widget_show (frame);
+  
+  vbox = gtk_vbox_new(FALSE, 0);
+  gtk_container_add (GTK_CONTAINER (frame), vbox);
+  gtk_widget_show (vbox);
+  
+  hbox = gtk_hbox_new(FALSE, 0);
+  gtk_container_border_width(GTK_CONTAINER(hbox), 10);
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
+  gtk_widget_show(hbox);
+  
+  prefs->DButton1 = gtk_radio_button_new_with_label (NULL, "New Document After Closing Last");
+  gtk_box_pack_start (GTK_BOX (hbox), prefs->DButton1, TRUE, TRUE, 0);
+  gtk_widget_show (prefs->DButton1);
+  
+  prefs->DButton2 = gtk_radio_button_new_with_label (
+	         gtk_radio_button_group (GTK_RADIO_BUTTON (prefs->DButton1)),
+		 "Close Window After Closing Last");
+  gtk_box_pack_start (GTK_BOX (hbox), prefs->DButton2, TRUE, TRUE, 0);
+  gtk_widget_show (prefs->DButton2);
+  
+  /* End of docyment closing stuffs */
+  
+  /* Print COmmand */
   frame = gtk_frame_new (_("Print Command"));
   gtk_box_pack_start (GTK_BOX (main_vbox), frame, TRUE, TRUE, 4);
   gtk_widget_show (frame);
@@ -265,6 +385,7 @@ static GtkWidget *print_page_new()
   prefs->pcmd = gtk_entry_new ();
   gtk_box_pack_start(GTK_BOX(hbox), prefs->pcmd, TRUE, TRUE, 0);
   gtk_widget_show (prefs->pcmd);
+  /* End Of Print Command */
   
   return main_vbox;
 }
@@ -404,9 +525,15 @@ static void plugins_fsel_ok (GtkWidget *w, GtkFileSelection *fs)
 static void plugins_clist_add (GtkWidget *w, gpointer data)
 {
  GtkWidget *fsel;
+ gchar *fname;
  
- 	fsel = gtk_file_selection_new ("Plugin Selector");
+ 	fsel = gtk_file_selection_new (_("Plugin Selector"));
  	gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (fsel));
+
+ 	fname = g_malloc (strlen (PLUGINDIR) + 3);
+ 	sprintf (fname, "%s/*", PLUGINDIR);
+ 	gtk_file_selection_set_filename (GTK_FILE_SELECTION (fsel), fname);
+ 	g_free (fname);
  	
  	gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (fsel)->ok_button),
 			  "clicked", GTK_SIGNAL_FUNC(plugins_fsel_ok),
@@ -432,7 +559,7 @@ static void plugins_clist_remove (GtkWidget *w, gpointer data)
   	
   	i  = (g_list_length (plugin_list)) - (GTK_CLIST(data)->focus_row);
   	
-  	gnome_app_remove_menu_range (GNOME_APP (prefs->gData->window->window),
+  	gnome_app_remove_menu_range (GNOME_APP (mdi->active_window),
   						path, i, 1);
 
   	for (i = 0; i < GTK_CLIST(data)->focus_row; i++);
@@ -481,7 +608,7 @@ static void plugins_toggle (GtkWidget *w)
   	path = g_new(gchar, strlen(_("_Plugins")) + 2);
   	sprintf(path, "%s/", _("_Plugins"));
   	
-  	gnome_app_remove_menu_range (GNOME_APP (prefs->gData->window->window),
+  	gnome_app_remove_menu_range (GNOME_APP (mdi->active_window),
   						path, 1, g_list_length (plugin_list));
      	
     }
@@ -504,7 +631,6 @@ static void plugins_toggle (GtkWidget *w)
  	   plugin_list = NULL;
  	   
  	plugin_load_list("gEdit");
- 	
   		
     }
 
@@ -543,7 +669,7 @@ static GtkWidget *plugins_page_new()
   gtk_widget_show(hbox);
   
 
-  prefs->plugins_toggle = gtk_check_button_new_with_label ("Use Plugins");
+  prefs->plugins_toggle = gtk_check_button_new_with_label (_("Use Plugins"));
    uP = gnome_config_get_int ("/Editor_Plugins/Use/gEdit");
   if (uP == -1)
     uP = 0;
@@ -625,6 +751,167 @@ static GtkWidget *plugins_page_new()
 
 /* End of Plugins Stuff... */
 
+/* MDI Stuff.. */
+
+
+static GtkWidget *mdi_page_new()
+{
+  GtkWidget *main_vbox, *vbox, *frame, *hbox;
+  GtkWidget *label;
+  gint i;
+
+  main_vbox = gtk_vbox_new (FALSE, 0);
+  gtk_container_border_width (GTK_CONTAINER (main_vbox), 4);
+  gtk_widget_show (main_vbox);
+  
+  frame = gtk_frame_new (_("MDI Mode"));
+  gtk_box_pack_start (GTK_BOX (main_vbox), frame, TRUE, TRUE, 4);
+  gtk_widget_show (frame);
+  
+  vbox = gtk_vbox_new(FALSE, 0);
+  gtk_container_add (GTK_CONTAINER (frame), vbox);
+  gtk_widget_show (vbox);
+  
+  prefs->mdi_list = NULL;
+  
+  for (i = 0; i < NUM_MDI_MODES; i++)
+     {
+       prefs->mdi_type[i] = GTK_RADIO_BUTTON
+        	(gtk_radio_button_new_with_label(prefs->mdi_list, _(mdi_type_label[i])));
+       
+       gtk_widget_show (GTK_WIDGET (prefs->mdi_type[i]));
+       gtk_box_pack_start(GTK_BOX(vbox), GTK_WIDGET(prefs->mdi_type[i]), TRUE, TRUE, 2);
+       prefs->mdi_list = gtk_radio_button_group (prefs->mdi_type[i]);
+     }
+  
+  return main_vbox;
+}
+
+/* End of MDI Stuff */
+
+/* Window Stuff.. */
+
+void use_current (GtkWidget *w, gpointer size)
+{
+
+	if (size == 0)
+	  gtk_entry_set_text (GTK_ENTRY (prefs->preW), prefs->curW);
+	else
+	  gtk_entry_set_text (GTK_ENTRY (prefs->preH), prefs->curH);
+
+}
+
+static GtkWidget *window_page_new()
+{
+  GtkWidget *main_vbox, *vbox, *vbox2, *frame, *hbox;
+  GtkWidget *label, *button;
+  gint i;
+  gchar *tmp;
+
+
+  prefs->curW = g_malloc (1);
+  prefs->curH = g_malloc (1);
+  sprintf (prefs->curW, "%d", GTK_WIDGET(mdi->active_window)->allocation.width);
+  sprintf (prefs->curH, "%d", GTK_WIDGET(mdi->active_window)->allocation.height);
+
+
+  main_vbox = gtk_vbox_new (FALSE, 0);
+  gtk_container_border_width (GTK_CONTAINER (main_vbox), 4);
+  gtk_widget_show (main_vbox);
+  
+  frame = gtk_frame_new (_("Window Size"));
+  gtk_box_pack_start (GTK_BOX (main_vbox), frame, TRUE, TRUE, 4);
+  gtk_widget_show (frame);
+  
+  vbox = gtk_vbox_new(FALSE, 0);
+  gtk_container_add (GTK_CONTAINER (frame), vbox);
+  gtk_widget_show (vbox);
+  
+  	hbox = gtk_hbox_new (FALSE, 0);
+  	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, FALSE, 2);
+  	gtk_container_border_width (GTK_CONTAINER (hbox), 4);
+  	gtk_widget_show (hbox);
+  
+  	label = gtk_label_new (_("Current Width:"));
+  	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+  	gtk_widget_show (label);
+  	
+  	prefs->cur = gtk_entry_new ();
+  	gtk_entry_set_text (GTK_ENTRY (prefs->cur), prefs->curW);
+ 	gtk_widget_set_sensitive (prefs->cur, FALSE);
+  	gtk_box_pack_start (GTK_BOX (hbox), prefs->cur, FALSE, FALSE, 3);
+  	gtk_widget_show (prefs->cur);
+
+  	
+  	vbox2 = gtk_vbox_new (FALSE, 0);
+  	gtk_box_pack_start (GTK_BOX (hbox), vbox2, FALSE, FALSE, 0);
+  	gtk_container_border_width (GTK_CONTAINER (vbox2), 1);
+  	gtk_widget_show (vbox2);
+  	
+  	hbox = gtk_hbox_new (FALSE, 0);
+  	gtk_box_pack_start (GTK_BOX (vbox2), hbox, TRUE, FALSE, 2);
+  	gtk_container_border_width (GTK_CONTAINER (hbox), 4);
+  	gtk_widget_show (hbox);
+
+  	label = gtk_label_new (_("Startup Width:"));
+  	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+  	gtk_widget_show (label);
+  	
+  	prefs->preW = gtk_entry_new ();
+  	gtk_box_pack_start (GTK_BOX (hbox), prefs->preW, FALSE, FALSE, 3);
+  	gtk_widget_show (prefs->preW);
+  	
+  	button = gtk_button_new_with_label (_("Use Current"));
+  	gtk_signal_connect (GTK_OBJECT (button), "clicked",
+  					GTK_SIGNAL_FUNC (use_current), (gint) 0);
+  	gtk_box_pack_start (GTK_BOX (vbox2), button, FALSE, FALSE, 4);
+  	gtk_widget_show (button);
+
+  	
+  	hbox = gtk_hbox_new (FALSE, 0);
+  	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, FALSE, 2);
+  	gtk_container_border_width (GTK_CONTAINER (hbox), 4);
+  	gtk_widget_show (hbox);
+  
+  	label = gtk_label_new (_("Current Height:"));
+  	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+  	gtk_widget_show (label);
+  	
+  	prefs->cur = gtk_entry_new ();
+	gtk_entry_set_text (GTK_ENTRY (prefs->cur), prefs->curH);
+ 	gtk_widget_set_sensitive (prefs->cur, FALSE);
+  	gtk_box_pack_start (GTK_BOX (hbox), prefs->cur, FALSE, FALSE, 3);
+  	gtk_widget_show (prefs->cur);
+  	
+  	vbox2 = gtk_vbox_new (FALSE, 0);
+  	gtk_box_pack_start (GTK_BOX (hbox), vbox2, FALSE, FALSE, 0);
+  	gtk_container_border_width (GTK_CONTAINER (vbox2), 1);
+  	gtk_widget_show (vbox2);
+  	
+  	hbox = gtk_hbox_new (FALSE, 0);
+  	gtk_box_pack_start (GTK_BOX (vbox2), hbox, TRUE, FALSE, 2);
+  	gtk_container_border_width (GTK_CONTAINER (hbox), 4);
+  	gtk_widget_show (hbox);
+  	  	
+  	label = gtk_label_new (_("Startup Height:"));
+  	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+  	gtk_widget_show (label);
+  	
+  	prefs->preH = gtk_entry_new ();
+  	gtk_box_pack_start (GTK_BOX (hbox), prefs->preH, FALSE, FALSE, 3);
+  	gtk_widget_show (prefs->preH);
+
+  	button = gtk_button_new_with_label (_("Use Current"));
+  	gtk_signal_connect (GTK_OBJECT (button), "clicked",
+  					GTK_SIGNAL_FUNC (use_current), (gint) 1);
+  	gtk_box_pack_start (GTK_BOX (vbox2), button, FALSE, FALSE, 4);
+  	gtk_widget_show (button);  	
+  
+  return main_vbox;
+}
+
+/* End of Window Stuff */
+
 void properties_modified (GtkWidget *widget, GnomePropertyBox *pbox)
 {
   gnome_property_box_changed (pbox);
@@ -634,7 +921,7 @@ void gE_prefs_dialog(GtkWidget *widget, gpointer cbdata)
 {
   static GnomeHelpMenuEntry help_entry = { NULL, "properties" };
   GtkWidget *label;
-
+  gint i;
   
   gE_data *data = (gE_data *)cbdata;
 
@@ -650,7 +937,6 @@ void gE_prefs_dialog(GtkWidget *widget, gpointer cbdata)
    prefs->pbox = (GNOME_PROPERTY_BOX (gnome_property_box_new ()));
    prefs->gData = data;
   
-
   gtk_signal_connect (GTK_OBJECT (prefs->pbox), "destroy",
 		      GTK_SIGNAL_FUNC (cancel), prefs);
 
@@ -671,21 +957,31 @@ void gE_prefs_dialog(GtkWidget *widget, gpointer cbdata)
   gtk_notebook_append_page ( GTK_NOTEBOOK( (prefs->pbox)->notebook),
                                            general_page_new(), label);
 
+  /* Window Settings */
+  label = gtk_label_new (_("Window"));
+  gtk_notebook_append_page (GTK_NOTEBOOK ( (prefs->pbox)->notebook),
+  									window_page_new(), label);
+
   /* Print Settings */
-  label = gtk_label_new (_("Print"));
+  label = gtk_label_new (_("Document"));
   gtk_notebook_append_page ( GTK_NOTEBOOK( (prefs->pbox)->notebook),
-                                           print_page_new(), label);
+                                           	doc_page_new(), label);
 
   /* Font Settings */
   label = gtk_label_new (_("Font"));
   gtk_notebook_append_page ( GTK_NOTEBOOK( (prefs->pbox)->notebook),
-                                           font_page_new(), label);
+                                           	font_page_new(), label);
   
   /* Plugins Settings */
   label = gtk_label_new (_("Plugins"));
   gtk_notebook_append_page ( GTK_NOTEBOOK( (prefs->pbox)->notebook),
                                            plugins_page_new(), label);
-    
+  
+  /* MDI Settings */
+  label = gtk_label_new (_("MDI"));
+  gtk_notebook_append_page (GTK_NOTEBOOK ( (prefs->pbox)->notebook),
+  										mdi_page_new(), label);
+  
   get_prefs(data);
 
 
@@ -705,7 +1001,23 @@ void gE_prefs_dialog(GtkWidget *widget, gpointer cbdata)
 
   gtk_signal_connect (GTK_OBJECT (prefs->font), "changed",
 		      GTK_SIGNAL_FUNC (properties_modified), prefs->pbox);
+
+  gtk_signal_connect (GTK_OBJECT (prefs->preW), "changed",
+		      GTK_SIGNAL_FUNC (properties_modified), prefs->pbox);
+
+  gtk_signal_connect (GTK_OBJECT (prefs->preH), "changed",
+		      GTK_SIGNAL_FUNC (properties_modified), prefs->pbox);
+
+  for (i = 0; i < NUM_MDI_MODES; i++)
+     gtk_signal_connect (GTK_OBJECT (prefs->mdi_type[i]), "clicked",
+		      GTK_SIGNAL_FUNC (properties_modified), prefs->pbox);
+
   
+  gtk_signal_connect (GTK_OBJECT (prefs->DButton1), "toggled",
+		      GTK_SIGNAL_FUNC (properties_modified), prefs->pbox);
+
+  gtk_signal_connect (GTK_OBJECT (prefs->DButton2), "toggled",
+		      GTK_SIGNAL_FUNC (properties_modified), prefs->pbox);
   
   gtk_widget_show_all (GTK_WIDGET (prefs->pbox));
                                     
