@@ -27,9 +27,12 @@
 #include "main.h"
 #include "commands.h"
 #include "gE_document.h"
+#include "gE_mdi.h"
 #include "gE_prefs.h"
 #include "gE_plugin_api.h"
 #include "gE_files.h"
+#include "menus.h"
+#include "toolbar.h"
 
 #ifdef WITH_GMODULE_PLUGINS
 #include <gE_plugin.h>
@@ -42,7 +45,13 @@
 GList *window_list;
 extern GList *plugins;
 plugin_callback_struct pl_callbacks;
+GnomeMDI *mdi;
+gE_window *window;
+gE_preference *settings;
 
+gint mdiMode = GNOME_MDI_DEFAULT_MODE;
+/*gint mdiMode = GNOME_MDI_NOTEBOOK;*/
+gboolean use_fontset = FALSE;
 
 void setup_callbacks( plugin_callback_struct *callbacks )
 {
@@ -63,20 +72,20 @@ void setup_callbacks( plugin_callback_struct *callbacks )
 	callbacks->document.get_position = NULL;
 	callbacks->document.get_selection = NULL;
 }
-
-gint file_open_wrapper (gE_data *data)
+/* We dont need this!
+gint file_open_wrapper (char *fname)
 {
-	char *nfile, *name;
+	char *nfile;
+	gE_document *doc;
 
-	name = data->temp2;
-	gE_document_new(data->window);
-	nfile = g_malloc(strlen(name)+1);
+	doc = gE_document_new();
+	nfile = g_malloc(strlen(fname)+1);
 	strcpy(nfile, name);
-	(gint) gE_file_open (data->window, gE_document_current(data->window), nfile);
+	(gint) gE_file_open (doc, nfile);
 
 	return FALSE;
 }
-
+*/
 
 
 GSList *launch_plugins = NULL;
@@ -152,13 +161,14 @@ corba_exception (CORBA_Environment* ev)
 
 int main (int argc, char **argv)
 {
-
+	gE_document *doc;
 	gE_window *window;
 	gE_data *data;
 	plugin_callback_struct callbacks;
 	char **args;
 	poptContext ctx;
 	int i;
+	GtkWidget *dummy_widget;
 
 	bindtextdomain(PACKAGE, GNOMELOCALEDIR);
 	textdomain(PACKAGE);
@@ -192,8 +202,17 @@ int main (int argc, char **argv)
 	
 #endif /* HAVE_LIBGNORBA */
 
-	g_slist_foreach(launch_plugins, launch_plugin, NULL);
-	g_slist_free(launch_plugins);
+	/* Determine we use fonts or fontsets. If a fontset is supplied
+	   for text widgets, we use fontsets for drawing texts. Otherwise
+	   we use normal fonts instead. */
+	dummy_widget = gtk_text_new(NULL, NULL);
+	gtk_widget_ensure_style(dummy_widget);
+	if (dummy_widget->style->font->type == GDK_FONT_FONTSET)
+		use_fontset = TRUE;
+	gtk_widget_destroy(dummy_widget);
+
+/*	g_slist_foreach(launch_plugins, launch_plugin, NULL);
+*/	g_slist_free(launch_plugins);
 
 	args = poptGetArgs(ctx);
 
@@ -203,38 +222,36 @@ int main (int argc, char **argv)
 	
 	poptFreeContext(ctx);
 	
-	gE_rc_parse();
+/*	gE_rc_parse(); -- THis really isnt needed any more.. but i forget the
+				  function itself.. */
 
 	doc_pointer_to_int = g_hash_table_new (g_direct_hash, g_direct_equal);
 	doc_int_to_pointer = g_hash_table_new (g_int_hash, g_int_equal);
 	win_pointer_to_int = g_hash_table_new (g_direct_hash, g_direct_equal);
 	win_int_to_pointer = g_hash_table_new (g_int_hash, g_int_equal);
-
+	
+	
 	data = g_malloc (sizeof (gE_data));
 	window_list = NULL;
-	window = gE_window_new();
-
-	data->window = window;
+	settings = g_malloc (sizeof (gE_preference));
 	
-	if (file_list){
-		gE_document *doc;
+	settings->num_recent = 0;
 
-		doc = gE_document_current(window);
-		gtk_notebook_remove_page(GTK_NOTEBOOK(window->notebook),
-					 gtk_notebook_current_page (GTK_NOTEBOOK(window->notebook)));
-		window->documents = g_list_remove(window->documents, doc);
-		if (doc->filename != NULL)
-			g_free (doc->filename);
-		g_free (doc);
+	mdi = GNOME_MDI(gnome_mdi_new ("gEdit", GEDIT_ID));
+	mdi->tab_pos = GTK_POS_TOP;
+	
+	gnome_mdi_set_menubar_template (mdi, gedit_menu);
+	gnome_mdi_set_toolbar_template (mdi, toolbar_data);
+	
+	gnome_mdi_set_child_menu_path (mdi, GNOME_MENU_FILE_STRING);
+	gnome_mdi_set_child_list_path (mdi, GNOME_MENU_FILES_PATH);
+	
 
-		for (;file_list; file_list = file_list->next)
-		{
-			data->temp2 = file_list->data;
-			file_open_wrapper (data);
-		}
-	}
+	/*window = gE_window_new();
+	
+	data->window = window;
+	window = g_malloc (sizeof (gE_window)); */
 
-	g_free (data);
 	/* Init plugins... */
 	plugins = NULL;
 	
@@ -244,11 +261,51 @@ int main (int argc, char **argv)
 	/*custom_plugin_query_all ( "/usr/gnome/libexec/plugins", &pl_callbacks);*/
 	/*custom_plugin_query ( "/usr/gnome/libexec", "print-plugin", &pl_callbacks);*/
 	plugin_load_list("gEdit");
+
+		
+    /* connect signals -- FIXME -- We'll do the rest later */
+    gtk_signal_connect(GTK_OBJECT(mdi), "remove_child", GTK_SIGNAL_FUNC(remove_doc_cb), NULL);
+    gtk_signal_connect(GTK_OBJECT(mdi), "destroy", GTK_SIGNAL_FUNC(file_quit_cb), NULL);
+/*    gtk_signal_connect(GTK_OBJECT(mdi), "view_changed", GTK_SIGNAL_FUNC(view_changed_cb), NULL);*/
+    gtk_signal_connect(GTK_OBJECT(mdi), "child_changed", GTK_SIGNAL_FUNC(child_switch), NULL);
+    gtk_signal_connect(GTK_OBJECT(mdi), "app_created", GTK_SIGNAL_FUNC(gE_window_new), NULL);
+    gtk_signal_connect(GTK_OBJECT(mdi), "add_view", GTK_SIGNAL_FUNC(add_view_cb), NULL);
+    gtk_signal_connect(GTK_OBJECT(mdi), "add_child", GTK_SIGNAL_FUNC(add_child_cb), NULL);		
+
+	gE_get_settings();
+/*	gnome_mdi_set_mode (mdi, mdiMode);	*/
+	gnome_mdi_set_mode (mdi, GNOME_MDI_NOTEBOOK);	
+		
+	gnome_mdi_open_toplevel(mdi);
+
+	if (file_list){
+
+	  if (mdi->active_child == NULL)
+	    return 1;
+	
+	  gnome_mdi_remove_child (mdi, mdi->active_child, FALSE);
+	
+		for (;file_list; file_list = file_list->next)
+		{
+			/*data->temp2 = file_list->data;*/
+			/*file_open_wrapper (file_list->data);*/
+			gE_document_new_with_file (file_list->data);
+		}
+	}
+/*	else
+	  doc = gE_document_new();
+*/	
+	
+	g_free (data);
+
+	
       
 #ifdef WITH_GMODULE_PLUGINS
 	gE_Plugin_Query_All ();
 #endif
 	
+
+	
 	gtk_main ();
 	return 0;
 }
