@@ -34,7 +34,7 @@
 #include "gE_prefs.h"
 #include "gE_prefs_box.h"
 #include "search.h"
-
+#include "gE_mdi.h"
 
 #define GE_DATA		1
 #define GE_WINDOW	2
@@ -77,19 +77,21 @@ char *just_a_quick_and_dirty_hack[]={
 	N_("Untitled")
 };
 
-
+	
 void add_callback_data (GnomeUIInfo *menu, gE_window *window, gE_data *data);
 void remove_callback_data (GnomeUIInfo *menu, gE_window *window, gE_data *data);
 
 GnomeUIInfo gedit_file_menu [] = {
         GNOMEUIINFO_MENU_NEW_ITEM(N_("_New"), N_("Create a new document"),
-				  file_new_cb, (gpointer) GE_DATA),
+				  file_new_cb, NULL),
 
-	GNOMEUIINFO_MENU_OPEN_ITEM(file_open_cb, (gpointer) GE_DATA),
+	GNOMEUIINFO_MENU_OPEN_ITEM(file_open_cb, NULL),
 
-	GNOMEUIINFO_MENU_SAVE_ITEM(file_save_cb, (gpointer) GE_DATA),
+	GNOMEUIINFO_MENU_SAVE_ITEM(file_save_cb, NULL),
 
-	GNOMEUIINFO_MENU_SAVE_AS_ITEM(file_save_as_cb, (gpointer) GE_DATA),
+	GNOMEUIINFO_MENU_SAVE_AS_ITEM(file_save_as_cb, NULL),
+
+	GNOMEUIINFO_ITEM_STOCK (N_("Revert"),NULL,file_revert_cb,GNOME_STOCK_MENU_REFRESH),
 
 	GNOMEUIINFO_SEPARATOR, 
 
@@ -99,9 +101,9 @@ GnomeUIInfo gedit_file_menu [] = {
 
 	GNOMEUIINFO_MENU_CLOSE_ITEM(file_close_cb, (gpointer) GE_DATA),
 
-	{ GNOME_APP_UI_ITEM, N_("Close All"), N_("Close all open files"),
-	  file_close_all_cb, (gpointer) GE_DATA, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE },
+/*BORK	{ GNOME_APP_UI_ITEM, N_("Close All"), N_("Close all open files"),
+FIXME	  file_close_all_cb, (gpointer) GE_DATA, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE },*/
 
 	GNOMEUIINFO_MENU_EXIT_ITEM(file_quit_cb, (gpointer) GE_DATA),
 
@@ -109,31 +111,6 @@ GnomeUIInfo gedit_file_menu [] = {
 };
 
 
-GnomeUIInfo gedit_edit_menu [] = {
-        GNOMEUIINFO_MENU_CUT_ITEM(edit_cut_cb, (gpointer) GE_DATA),
-
-        GNOMEUIINFO_MENU_COPY_ITEM(edit_copy_cb, (gpointer) GE_DATA),
-
-	GNOMEUIINFO_MENU_PASTE_ITEM(edit_paste_cb, (gpointer) GE_DATA),
-
-	GNOMEUIINFO_MENU_SELECT_ALL_ITEM(edit_selall_cb, (gpointer) GE_DATA),
-
-
-	GNOMEUIINFO_SEPARATOR,
-
-	{ GNOME_APP_UI_ITEM, N_("Find _Line..."),
-	  N_("Search for a line"),
-	  goto_line_cb, (gpointer) GE_WINDOW, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH },
-
-	GNOMEUIINFO_MENU_FIND_ITEM(search_cb, (gpointer) GE_DATA),
-
-	GNOMEUIINFO_MENU_FIND_AGAIN_ITEM(search_again_cb, (gpointer) GE_DATA),
-
-	GNOMEUIINFO_MENU_REPLACE_ITEM(search_replace_cb, (gpointer) GE_DATA),
-	
-	GNOMEUIINFO_END
-};	
 
 GnomeUIInfo gedit_tab_menu []= {
 	{ GNOME_APP_UI_ITEM, N_("_Top"),
@@ -152,16 +129,30 @@ GnomeUIInfo gedit_tab_menu []= {
 	  N_("Put the document tabs on the right"),
 	  tab_rgt_cb, (gpointer) GE_WINDOW, NULL },
 
-	GNOMEUIINFO_SEPARATOR,
+/*	GNOMEUIINFO_SEPARATOR,
 
 	GNOMEUIINFO_TOGGLEITEM_DATA(GE_TOGGLE_LABEL_SHOWTABS,
 			    N_("Toggle the presence of the document tabs"),
-				    tab_toggle_cb, (gpointer) GE_WINDOW, NULL),
+				    tab_toggle_cb, (gpointer) GE_WINDOW, NULL),*/
 	
 	GNOMEUIINFO_END
 };
 
+GnomeUIInfo gedit_scrbar_menu []= {
+	{ GNOME_APP_UI_ITEM, N_("_None"),
+	  N_("Don't have a scrollbar"),
+	  scrollbar_none_cb, (gpointer) GE_DATA, NULL },
 
+	{ GNOME_APP_UI_ITEM, N_("_Always"),
+	  N_("Always have the scrollbar"),
+	  scrollbar_always_cb, (gpointer) GE_DATA, NULL },
+
+	{ GNOME_APP_UI_ITEM, N_("_Automatic"),
+	  N_("Only have scrollbar when it's needed"),
+	  scrollbar_auto_cb, (gpointer) GE_DATA, NULL },
+
+	GNOMEUIINFO_END
+};
 
 
 GnomeUIInfo gedit_settings_menu []= {
@@ -173,32 +164,35 @@ GnomeUIInfo gedit_settings_menu []= {
 	GNOMEUIINFO_TOGGLEITEM_DATA(GE_TOGGLE_LABEL_STATUSBAR,
 				    N_("Toggle statusbar"),
 				    options_toggle_status_bar_cb,
-				    (gpointer) GE_WINDOW, NULL),
+				    NULL, NULL),
 
 	GNOMEUIINFO_TOGGLEITEM_DATA(GE_TOGGLE_LABEL_WORDWRAP,
 				    N_("Toggle Wordwrap"),
 				    options_toggle_word_wrap_cb,
-				    (gpointer) GE_WINDOW, NULL),
+				    NULL, NULL),
 
 	GNOMEUIINFO_TOGGLEITEM_DATA(GE_TOGGLE_LABEL_LINEWRAP,
 				    N_("Toggle Linewrap"),
 				    options_toggle_line_wrap_cb,
-				    (gpointer) GE_WINDOW, NULL),
+				    NULL, NULL),
 
 	GNOMEUIINFO_TOGGLEITEM_DATA(GE_TOGGLE_LABEL_READONLY,
 				    N_("Toggle Readonly"),
 				    options_toggle_read_only_cb,
-				    (gpointer) GE_WINDOW, NULL),
+				    NULL, NULL),
 
 	GNOMEUIINFO_TOGGLEITEM_DATA(GE_TOGGLE_LABEL_SPLITSCREEN,
 				    N_("Toggle Split Screen"),
 				    options_toggle_split_screen_cb,
-				    (gpointer) GE_WINDOW, NULL),
+				    NULL, NULL),
 
 	GNOMEUIINFO_SEPARATOR,
 
 	{ GNOME_APP_UI_SUBTREE, N_("_Document Tabs"),
 	  N_("Change the placement of the document tabs"), &gedit_tab_menu },
+	  
+	{ GNOME_APP_UI_SUBTREE, N_("_Scrollbar"),
+	  N_("Change visibility options of the scrollbar"), &gedit_scrbar_menu },
 
 	GNOMEUIINFO_SEPARATOR,
 
@@ -214,21 +208,25 @@ GnomeUIInfo gedit_settings_menu []= {
 };
 
 GnomeUIInfo gedit_window_menu []={
-        GNOMEUIINFO_MENU_NEW_WINDOW_ITEM(window_new_cb, (gpointer) GE_DATA),
+ 	GNOMEUIINFO_MENU_NEW_WINDOW_ITEM(window_new_cb, (gpointer) GE_DATA),
 
-        GNOMEUIINFO_MENU_CLOSE_WINDOW_ITEM(window_close_cb,
-					   (gpointer) GE_DATA),
+/*FIXME        GNOMEUIINFO_MENU_CLOSE_WINDOW_ITEM(window_close_cb,
+					   (gpointer) GE_DATA),*/
 	
-	GNOMEUIINFO_SEPARATOR,
+/*	GNOMEUIINFO_SEPARATOR,
 
 	{ GNOME_APP_UI_ITEM, N_("_Document List"),
 	  N_("Display the document list"),
 	  files_list_popup, (gpointer) GE_DATA, NULL,
-	  GNOME_APP_PIXMAP_NONE, NULL, 'L', GDK_CONTROL_MASK, NULL },
+	  GNOME_APP_PIXMAP_NONE, NULL, 'L', GDK_CONTROL_MASK, NULL },*/
 
 	GNOMEUIINFO_END
 };
 
+GnomeUIInfo gedit_docs_menu[] = {
+	GNOMEUIINFO_END
+};
+
 GnomeUIInfo gedit_help_menu []= {
 
 	GNOMEUIINFO_HELP ("gedit"),
@@ -249,18 +247,14 @@ GnomeUIInfo gedit_plugins_menu []= {
 GnomeUIInfo gedit_menu [] = {
         GNOMEUIINFO_MENU_FILE_TREE(gedit_file_menu),
 
-	GNOMEUIINFO_MENU_EDIT_TREE(gedit_edit_menu),
-
-
 #if PLUGIN_TEST
 	{ GNOME_APP_UI_SUBTREE, N_("_Plugins"), NULL, &gedit_plugins_menu, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
 #endif
 
 	GNOMEUIINFO_MENU_SETTINGS_TREE(gedit_settings_menu),
-
 	GNOMEUIINFO_MENU_WINDOWS_TREE(gedit_window_menu),
-
+	GNOMEUIINFO_MENU_FILES_TREE(gedit_docs_menu),
 	GNOMEUIINFO_MENU_HELP_TREE(gedit_help_menu),
 
 	GNOMEUIINFO_END
@@ -268,22 +262,24 @@ GnomeUIInfo gedit_menu [] = {
 
 GnomeUIInfo * gE_menus_init (gE_window *window, gE_data *data)
 {
-	add_callback_data (gedit_file_menu, window, data);
-	add_callback_data (gedit_edit_menu, window, data);
+/*	add_callback_data (gedit_file_menu, GNOME_APP (mdi->active_window), data);
+	add_callback_data (gedit_edit_menu, GNOME_APP (mdi->active_window), data);
 	add_callback_data (gedit_tab_menu, window, data);
-	add_callback_data (gedit_settings_menu, window, data);
-	add_callback_data (gedit_window_menu, window, data);
-	add_callback_data (gedit_help_menu, window, data);
-
-	gnome_app_create_menus (GNOME_APP (window->window), gedit_menu);
-
-	remove_callback_data (gedit_file_menu, window, data);
-	remove_callback_data (gedit_edit_menu, window, data);
-	remove_callback_data (gedit_tab_menu, window, data);
-	remove_callback_data (gedit_settings_menu, window, data);
-	remove_callback_data (gedit_window_menu, window, data);
-	remove_callback_data (gedit_help_menu, window, data);
+	add_callback_data (gedit_settings_menu,GNOME_APP (mdi->active_window), data);
+	add_callback_data (gedit_window_menu, GNOME_APP (mdi->active_window), data);
+	add_callback_data (gedit_docs_menu, GNOME_APP (mdi->active_window), data);
+	add_callback_data (gedit_help_menu, GNOME_APP (mdi->active_window), data);
+*/
+	gnome_app_create_menus (GNOME_APP (mdi->active_window), gedit_menu);
 
+/*	remove_callback_data (gedit_file_menu, GNOME_APP (mdi->active_window), data);
+	remove_callback_data (gedit_edit_menu, GNOME_APP (mdi->active_window), data);
+	remove_callback_data (gedit_tab_menu, GNOME_APP (mdi->active_window),data);
+       remove_callback_data (gedit_settings_menu,GNOME_APP (mdi->active_window), data);
+	remove_callback_data (gedit_window_menu,GNOME_APP (mdi->active_window),data);
+	remove_callback_data (gedit_docs_menu, GNOME_APP (mdi->active_window), data);
+	remove_callback_data (gedit_help_menu, GNOME_APP (mdi->active_window), data);
+*/
 	return (GnomeUIInfo *) gedit_menu;
 }
 
@@ -292,9 +288,9 @@ GnomeUIInfo * gE_menus_init (gE_window *window, gE_data *data)
  * It is called from gE_window_nwe after the settings have been loaded.
  */
 void
-gE_set_menu_toggle_states(gE_window *w)
+gE_set_menu_toggle_states()
 {
-  gE_document *doc = gE_document_current (w);
+  gE_document *doc;
   int i;
 
 #define GE_SET_TOGGLE_STATE(item, l, boolean)                            \
@@ -303,16 +299,18 @@ gE_set_menu_toggle_states(gE_window *w)
 
   /*
    * Initialize the states of the document tabs menu...
+   * FIXME: This is borked right now.. does GnomeMDI need this? 
+   *  	    An addition to the prefs box would be better..
    */
-  for (i = 0; gedit_tab_menu[i].type != GNOME_APP_UI_ENDOFINFO; i++)
+/*  for (i = 0; gedit_tab_menu[i].type != GNOME_APP_UI_ENDOFINFO; i++)
     {
       if (gedit_tab_menu[i].label)
 	{
 	  GE_SET_TOGGLE_STATE(gedit_tab_menu[i], GE_TOGGLE_LABEL_SHOWTABS,
-			      w->show_tabs);
+			      settings->show_tabs);
 	  
 	}
-    }
+    }*/
 
 
   /*
@@ -324,12 +322,14 @@ gE_set_menu_toggle_states(gE_window *w)
 	{
 	  GE_SET_TOGGLE_STATE(gedit_settings_menu[i],
 			      _(GE_TOGGLE_LABEL_AUTOINDENT),
-			      w->auto_indent);
+			      settings->auto_indent);
 
 	  GE_SET_TOGGLE_STATE(gedit_settings_menu[i],
 			      _(GE_TOGGLE_LABEL_STATUSBAR),
-			      w->show_status);
+			      settings->show_status);
 
+      if ((doc = gE_document_current ()))
+        {
 	  GE_SET_TOGGLE_STATE(gedit_settings_menu[i],
 			      _(GE_TOGGLE_LABEL_WORDWRAP),
 			      doc->word_wrap);
@@ -344,8 +344,9 @@ gE_set_menu_toggle_states(gE_window *w)
 
 	  GE_SET_TOGGLE_STATE(gedit_settings_menu[i],
 			      _(GE_TOGGLE_LABEL_SPLITSCREEN),
-			      doc->window->splitscreen);
+			      doc->splitscreen);
 
+	 }
 	}
     }
 }
