@@ -23,8 +23,10 @@
 extern "C" {
 #endif /* __cplusplus */
 
+extern GnomeUIInfo gedit_menu [];
+
 extern GnomeUIInfo * gE_menus_init(gE_window *window, gE_data *data);
-void gE_set_menu_toggle_states(gE_window *w);
+void gE_set_menu_toggle_states();
    
 #ifdef __cplusplus
 }
